==> jc-1.4.0.tar.gz: gnu/java/net/LineInputStream.h <==
// public class gnu.java.net.LineInputStream

// class file dependencies
// @dep_class a490bbd246f20a0f gnu_java_net_LineInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_LineInputStream_H_
#define _JC_gnu_java_net_LineInputStream_H_

// Forward structure declarations
struct _jc_java_io_ByteArrayOutputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_LineInputStream$sub_refs	_jc_gnu_java_net_LineInputStream$sub_refs;
typedef struct _jc_gnu_java_net_LineInputStream$sub_nonrefs	_jc_gnu_java_net_LineInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_LineInputStream$refs	_jc_gnu_java_net_LineInputStream$refs;
typedef struct _jc_gnu_java_net_LineInputStream$nonrefs	_jc_gnu_java_net_LineInputStream$nonrefs;
typedef struct _jc_gnu_java_net_LineInputStream$object	_jc_gnu_java_net_LineInputStream$object;

typedef const struct _jc_gnu_java_net_LineInputStream$vmethods	_jc_gnu_java_net_LineInputStream$vmethods;
typedef const struct _jc_gnu_java_net_LineInputStream$vtable	_jc_gnu_java_net_LineInputStream$vtable;
typedef const struct _jc_gnu_java_net_LineInputStream$vtype	_jc_gnu_java_net_LineInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_LineInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_java_io_InputStream$object *);
extern void _jc_gnu_java_net_LineInputStream$method$_init$e001e34d89a02dc4(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_gnu_java_net_LineInputStream$method$indexOf$3c9eb765f763207c(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_byte_array *, jint, jbyte);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_LineInputStream$method$readLine$d32396e6ff161651(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_LineInputStream$method_info$indexOf$3c9eb765f763207c;
extern _jc_method _jc_gnu_java_net_LineInputStream$method_info$readLine$d32396e6ff161651;

// Virtual methods structure
struct _jc_gnu_java_net_LineInputStream$vmethods {
	jint	(*indexOf$3c9eb765f763207c)(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_byte_array *, jint, jbyte);
	struct _jc_java_lang_String$object	*(*readLine$d32396e6ff161651)(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_LineInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_LineInputStream$vmethods	gnu_java_net_LineInputStream;
};

// Vtype
struct _jc_gnu_java_net_LineInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_LineInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_LineInputStream$sub_refs {
	struct _jc_java_io_ByteArrayOutputStream$object	*buf;
	struct _jc_java_lang_String$object	*encoding;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_LineInputStream$refs {
    _jc_gnu_java_net_LineInputStream$sub_refs	gnu_java_net_LineInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_LineInputStream$sub_nonrefs {
	jboolean	eof;
	jboolean	blockReads;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_LineInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_LineInputStream$sub_nonrefs	gnu_java_net_LineInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_LineInputStream$object {
	_jc_gnu_java_net_LineInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_LineInputStream$vtype	*vtype;
	_jc_gnu_java_net_LineInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_LineInputStream$vtype _jc_gnu_java_net_LineInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_LineInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_LineInputStream$class_object;

#endif	/* _JC_gnu_java_net_LineInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/LineInputStream.h <==
// public class gnu.java.net.LineInputStream

// class file dependencies
// @dep_class a490bbd246f20a0f gnu_java_net_LineInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_LineInputStream_H_
#define _JC_gnu_java_net_LineInputStream_H_

// Forward structure declarations
struct _jc_java_io_ByteArrayOutputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_LineInputStream$sub_refs	_jc_gnu_java_net_LineInputStream$sub_refs;
typedef struct _jc_gnu_java_net_LineInputStream$sub_nonrefs	_jc_gnu_java_net_LineInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_LineInputStream$refs	_jc_gnu_java_net_LineInputStream$refs;
typedef struct _jc_gnu_java_net_LineInputStream$nonrefs	_jc_gnu_java_net_LineInputStream$nonrefs;
typedef struct _jc_gnu_java_net_LineInputStream$object	_jc_gnu_java_net_LineInputStream$object;

typedef const struct _jc_gnu_java_net_LineInputStream$vmethods	_jc_gnu_java_net_LineInputStream$vmethods;
typedef const struct _jc_gnu_java_net_LineInputStream$vtable	_jc_gnu_java_net_LineInputStream$vtable;
typedef const struct _jc_gnu_java_net_LineInputStream$vtype	_jc_gnu_java_net_LineInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_LineInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_LineInputStream$method$_init$e001e34d89a02dc4(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_LineInputStream$method$indexOf$3c9eb765f763207c(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_byte_array *, jint, jbyte) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_LineInputStream$method$readLine$d32396e6ff161651(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_LineInputStream$method_info$indexOf$3c9eb765f763207c;
extern _jc_method _jc_gnu_java_net_LineInputStream$method_info$readLine$d32396e6ff161651;

// Virtual methods structure
struct _jc_gnu_java_net_LineInputStream$vmethods {
	jint	(*indexOf$3c9eb765f763207c)(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *, struct _jc_byte_array *, jint, jbyte) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*readLine$d32396e6ff161651)(_jc_env *, struct _jc_gnu_java_net_LineInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_LineInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_LineInputStream$vmethods	gnu_java_net_LineInputStream;
};

// Vtype
struct _jc_gnu_java_net_LineInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_LineInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_LineInputStream$sub_refs {
	struct _jc_java_io_ByteArrayOutputStream$object	*buf;
	struct _jc_java_lang_String$object	*encoding;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_LineInputStream$refs {
    _jc_gnu_java_net_LineInputStream$sub_refs	gnu_java_net_LineInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_LineInputStream$sub_nonrefs {
	jboolean	eof;
	jboolean	blockReads;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_LineInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_LineInputStream$sub_nonrefs	gnu_java_net_LineInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_LineInputStream$object {
	_jc_gnu_java_net_LineInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_LineInputStream$vtype	*vtype;
	_jc_gnu_java_net_LineInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_LineInputStream$vtype _jc_gnu_java_net_LineInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_LineInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_LineInputStream$class_object;

#endif	/* _JC_gnu_java_net_LineInputStream_H_ */
